==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/de_DE.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Passwort:",
    "Generating system report failed." : "Erstellung des System-Berichts fehlgeschlagen.",
    "Subscription notifications" : "Abonnements-Benachrichtigungen",
    "Could not create folder \"System information\" to store generated report." : "Ordner \"System information\" konnte nicht erstellt werden, um den erstellten Bericht zu speichern.",
    "Could not create file \"%s\" to store generated report." : "Die Datei \"%s\" konnte nicht erstellt werden, um in ihr den erstellten Bericht zu speichern.",
    "Could not share file \"%s\"." : "Die Datei \"%s\" konnte nicht freigegeben werden.",
    "Nextcloud Subscription" : "Nextcloud-Abonnement",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Ihr Server hat kein Nextcloud-Abonnement oder Ihr Abonnement ist abgelaufen.",
    "Your Nextcloud server subscription does not cover your number of users." : "Ihr Nexcloud-Abonnement umfasst nicht die Anzahl Ihrer Nutzer.",
    "Your Nextcloud Subscription has expired!" : "Ihr Nextcloud-Abonnement ist abgelaufen!",
    "Your server has no Nextcloud Subscription" : "Ihr Server hat kein Nextcloud-Abonnement",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Ihr Server wird nicht von einem Nextcloud-Enterprise-Abonnement umfasst.",
    "A Nextcloud Support Subscription means the original developers behind your private cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Ein Nextcloud-Support-Abonnement bedeutet, dass sich die Entwickler Ihrer privaten Cloud-Server zu 100 % Ihrem Erfolg widmen: der Sicherheit, Skalierbarkeit, Leistung und Funktionalität Ihres Dienstes.",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "Wenn Sie auf ein Problem stoßen und Ihr Server nicht länger funktioniert, Mitarbeiter oder Kunden keine Dateien mehr herunter- oder hochladen können, dann müssen Sie nicht online suchen oder Freiwillige in Foren oder Sozialen Medien fragen, um eine Lösung zu finden. Sie haben direkten Zugang zu unseren erfahrenen Entwicklern, welche Ihnen helfen, das Problem zu finden und zu beheben.",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "Sie haben einen Vertrag mit dem Anbieter, der Ihnen vertrauliche Sicherheitsinformationen, Risikominderungen, Patches und Aktualisierungen bereitstellt.",
    "If you want to skip a release or two and stay a bit longer on your current version without disruptions, you don't have to run software without security updates. We deliver them to you as long as is needed!" : "Wenn Sie ein oder zwei Versionen überspringen möchten und etwas länger ihre installierte Version ohne Unterbrechung behalten möchten, müssen Sie auf Sicherheitsupdates nicht verzichten. Wir liefern Diese so lange, wie es erforderlich ist.",
    "If you have performance and scalability issues you have the best expertise at hand, instead of having to search on the web and hope you find a solution." : "Wenn Sie Leistungs- oder Skalierungsprobleme haben sollten, haben Sie direkt die größte Erfahrung zur Hand und müssen nicht das Netz in der Hoffnung, eine Lösung zu finden, durchsuchen.",
    "If you are asked how the compliance of Nextcloud is and if you can deliver a data export under GDPR, HIPAA or other rules, you have access to the right documentation and can tap into our expertise to respond quickly and accurately." : "Wenn Sie bezüglich der Compliance von Nextcloud gefragt werden können Sie einen Datenexport liefern, der der DSGVO, der HIPAA oder anderen Regelungen entspricht. Außerdem haben Sie Zugriff auf die erforderlichen Dokumentation und unsere Erfahrung um schnell und vollständig antworten zu können.",
    "We can also provide you Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a very limited form for free. And we can develop further integrations and capabilities you need." : "Wir können Ihnen auch Outlook-Integration, Online-Office, skalierbare integrierte Audio-, Video- und Chat-Kommunikation sowie weitere Funktionen, die sonst nur in beschränkter Form kostenlos erhältlich sind, anbieten. Ausserdem können wir weitere Erweiterungen, die Sie benötigen, entwickeln.",
    "A subscription helps you get the most out of Nextcloud! Don't your users deserve the best?" : "Ein Abonnement hilft Ihnen das Beste aus Nextcloud herauszuholen! Haben Ihre Nutzer nicht das Beste verdient?",
    "Learn more now" : "Erfahren Sie jetzt mehr",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Diese E-Mail wurde von der Support-App Ihrer Nextcloud-Instanz unter %1$s an alle Administratoren verschickt, weil über %2$s registrierte Benutzer vorhanden sind.",
    "Your Nextcloud server Subscription is over limit" : "Ihr Nextcloud-Server-Abonnement ist über dem Limit",
    "Dear admin," : "Sehr gehrter Administrator,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "Ihr Nextcloud-Abonnement umfasst nicht die Anzahl der aktuell auf diesem Server aktiven Nutzer. Bitte kontaktieren Sie Ihren Accountmanager, um Ihr Abonnement aktualisieren zu lassen!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s ist Ihr Accountmanager und ist per E-Mail über %2$soder telefonisch unter %3$s erreichbar.",
    "Thank you," : "Dankeschön,",
    "Your Nextcloud team" : "Ihr Nextcloud-Team",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than what your subscription covers." : "Diese E-Mail wurde von der Support-App Ihrer Nextcloud-Instanz unter %s an alle Administratoren verschickt, weil mehr Benutzer registriert sind als das Nextcloud-Abonnement abdeckt.",
    "Your Nextcloud server Subscription is expired" : "Ihr Nextcloud-Server-Abonnement ist abgelaufen",
    "Your Nextcloud server Subscription is expired!" : "Ihr Nextcloud-Server-Abonnement ist abgelaufen!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "Ihr Nextcloud Abonnement ist abgelaufen! Bitte kontaktieren Sie Ihren Accountmanager um das Abonnement verlängert zu bekommen.",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Diese E-Mail wurde von der Support-App Ihrer Nextcloud-Instanz unter %s an alle Administratoren verschickt, weil Ihr Nextcloud-Abonnement abgelaufen ist.",
    "Support" : "Support",
    "Getting support and help for your Nextcloud" : "Erhalten Sie Support und Hilfe für Ihre Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Die Support-App bietet direkten Zugriff auf Hilfe- und Vertriebsquellen, direkte Kontaktmöglichkeiten zum Accountmanager sowie einen Überblick über das Enterprise-Abonnement.",
    "Basic subscription" : "Basis Abonnement",
    "Standard subscription" : "Standard Abonnement",
    "Premium subscription" : "Premium Abonnement",
    "Géant subscription" : "Géant Abonnement",
    "Silver partner subscription" : "Silber-Partner Abonnement",
    "Gold partner subscription" : "Gold-Partner Abonnement",
    "Subscription" : "Abonnement",
    "Over subscription limit" : "Abonnements-Limit überschritten",
    "Valid subscription" : "Gültiges Abonnement",
    "Expired subscription" : "Abgelaufenes Abonnement",
    "Subscription key:" : "Abonnements-Schlüssel:",
    "_Expires in %n year_::_Expires in %n years_" : ["Läuft ab in %n Jahr","Läuft ab in %n Jahren"],
    "_Expires in %n month_::_Expires in %n months_" : ["Läuft ab in %n Monat","Läuft ab in %n Monaten"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Läuft ab in %n Woche","Läuft ab in %n Wochen"],
    "_Expires in %n day_::_Expires in %n days_" : ["Läuft ab in %n Tage","Läuft ab in %n Tagen"],
    "_For %n users_::_For %n users_" : ["Für %n  Nutzer","Für  %n Nutzer"],
    "_currently at %n user_::_currently at %n users_" : ["aktuell mit %n  Nutzer","aktuell mit %n Nutzern"],
    "Includes support for %s" : "Beinhaltet Support für %s",
    "Includes support for %1$s & %2$s" : "Beinhaltet Support für %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Beinhaltet Support für %1$s, %2$s & %3$s",
    "Update subscription key" : "Abonnements-Schlüssel aktualisieren",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s ist Ihr Accountmanager. Zögeren Sie nicht, uns bezüglich Fragen zu Ihrem Abonnement anzusprechen.",
    "You can find answers to common question in our portal and also file support requests there." : "In unserem Portal finden Sie Antworten auf häufige Fragen und können auch Unterstützung anfordern.",
    "Access Nextcloud portal" : "Zum Nextcloud-Portal",
    "System information" : "Systeminformation",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Erstellen von Systeminformationen für Supportfälle. Nach Betätigung der Schaltfläche wird eine Textdatei im Ordner \"System information\" erstellt und über eine passwortgeschütze, öffentliche Freigabe geteilt. Der Link ist 2 Wochen lang aktiv.",
    "Generate system report" : "System-Bericht erstellen",
    "Enterprise subscription recommended" : "Enterprise-Abonnement empfohlen",
    "No active enterprise subscription" : "Kein aktives Enterprise-Abonnement",
    "Unsupported" : "Nicht unterstützt",
    "This Nextcloud server has no Enterprise Subscription." : "Dieser Nextcloud-Server verfügt über kein Enterprise-Abonnement.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Ein Nextcloud Enterprise-Abonnement hilft Ihnen, das Meiste aus Ihrer Nextcloud herauszuholen, Ihre Daten abzusichern und Ihren Server zuverlässig laufen zu lassen.",
    "Advantages" : "Vorteile",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Ein Nextcloud Enterprise-Abonnenment hilft Ihnen, das meiste aus Ihrer Nextcloud herauszuholen, Ihre Daten abzusichern und Ihren Server jederzeit zuverlässig zu betreiben.",
    "Access to additional capabilities like Outlook integration, online office and more" : "Zugriff auf weitere Funktionen wie Outlook-Integration, Online-Office, usw.",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Zugriff auf Skalierbarkeits-Sachverstand und Skalierbarkeits-Fähigkeiten für Dateien und Talk",
    "Optional branding, consulting, architecture advice" : "Optional Unterstützung bezüglich Branding, Beratung und Architektur",
    "Confidential security notification service, mitigations, patches and advice" : "Vertraulicher Sicherheitsbenachrichtigungsdienst, Risikominderung, Patches und Hilfestellungen",
    "Compliance certification, advice and documentation" : "Compliance-Zertifizierung, Beratung und Dokumentation",
    "Get a quote" : "Erhalten Sie ein Angebot",
    "More information" : "Mehr Informationen",
    "Subscription benefits" : "Abonnement-Vorteile",
    "Pricing" : "Preisgestaltung",
    "Commmunity support" : "Community-Unterstützung",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud ist eine freie Software, die von einer sehr aktive Community unterstützt wird. Bitte melden Sie sich im Forum an um Fragen zu stellen oder mit anderen zu diskutieren.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud verwendet GitHub als Plattform für die Zusammenarbeit. Sie können dort Fehler direkt melden.",
    "Chat" : "Chat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Chatten Sie mit uns über den IRC-Kanal #nextcloud auf Freenode.",
    "Nextcloud forum" : "Nextcloud Forum",
    "Nextcloud at GitHub" : "Nextcloud auf GitHub",
    "Open chat" : "Chat öffnen",
    "Subscription key" : "Abonnements-Schlüssel",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Wenn Sie über ein aktives Nextcloud-Abonnement verfügen, geben SIe bitte hier Ihren Abonnements-Schlüssel ein.",
    "Learn more about an enterprise subscription." : "Erfahren Sie mehr über das Enterprise-Abonnement.",
    "Set subscription key" : "Abonnements-Schlüssel eingeben",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Die Abonnenments-Informationen konnten soeben nicht abgerufen werden. Eine Wiederholung ist geplant. Bitte später noch einmal überprüfen.",
    "The subscription key was invalid." : "Der Abonnements-Schlüssel ist ungültig.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Der Abonnements-Schlüssel konnte nicht überprüft werden, da dieser Server nicht mit dem Internet verbunden ist. Bitte wenden Sie sich zur Fehlerbehebung an das Support-Team.",
    "The subscription key had an invalid format." : "Der Abonnements-Schlüssel hat ein ungültiges Format.",
    "While fetching the subscription information an error happened." : "Beim Abruf der Abonnements-Informationen ist ein Fehler aufgetreten",
    "News" : "Neuigkeiten",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Abonnieren Sie unseren Newsletter und folgen Sie uns auf unseren Social-Media-Kanälen um bezüglich der Nexcloud-Entwicklung immer auf dem Laufenden zu sein.",
    "Follow us on Google+" : "Folgen Sie uns auf Google+",
    "Like our Facebook page" : "Liken Sie uns auf unserer Facebook-Seite",
    "Follow us on Twitter" : "Folgen Sie uns auf Twitter",
    "Check out our blog" : "Sehen Sie sich unseren Blog an",
    "Subscribe to our newsletter" : "Abonnieren Sie unseren Newsletter"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/de_DE.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Passwort:",
    "Generating system report failed." : "Erstellung des System-Berichts fehlgeschlagen.",
    "Subscription notifications" : "Abonnements-Benachrichtigungen",
    "Could not create folder \"System information\" to store generated report." : "Ordner \"System information\" konnte nicht erstellt werden, um den erstellten Bericht zu speichern.",
    "Could not create file \"%s\" to store generated report." : "Die Datei \"%s\" konnte nicht erstellt werden, um in ihr den erstellten Bericht zu speichern.",
    "Could not share file \"%s\"." : "Die Datei \"%s\" konnte nicht freigegeben werden.",
    "Nextcloud Subscription" : "Nextcloud-Abonnement",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Ihr Server hat kein Nextcloud-Abonnement oder Ihr Abonnement ist abgelaufen.",
    "Your Nextcloud server subscription does not cover your number of users." : "Ihr Nexcloud-Abonnement umfasst nicht die Anzahl Ihrer Nutzer.",
    "Your Nextcloud Subscription has expired!" : "Ihr Nextcloud-Abonnement ist abgelaufen!",
    "Your server has no Nextcloud Subscription" : "Ihr Server hat kein Nextcloud-Abonnement",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Ihr Server wird nicht von einem Nextcloud-Enterprise-Abonnement umfasst.",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Ein Nextcloud-Unternehmens-Abonnement bedeutet, dass sich die Entwickler hinter Ihrem  privaten Cloud-Server zu 100 % Ihrem Erfolg widmen: der Sicherheit, Skalierbarkeit, Leistung und Funktionalität Ihres Dienstes!",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Wenn Ihre Serverkonfiguration gestört ist und Mitarbeiter nicht mehr arbeiten können, müssen Sie sich nicht darauf verlassen, dass Sie in Online-Foren nach einer Lösung suchen. Sie haben direkten Zugang zu unseren erfahrenen Ingenieuren!",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Sie haben einen Vertrag mit dem Anbieter, der frühzeitige Sicherheitsinformationen, Maßnahmen, Patches und Updates bereitstellt.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Wenn Sie länger und ohne Unterbrechungen auf Ihrer aktuellen Version bleiben müssen, müssen Sie keine Software ohne Sicherheitsupdates betreiben.",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Sie haben Zugriff auf das beste Know-how, um Probleme bezüglich Leistung und Skalierbarkeit zu lösen.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Sie haben Zugriff auf die richtige Dokumentation und das richtige Fachwissen, um Fragen zur Compliance, GDPR, HIPAA und andere Vorschriften schnell beantworten zu können.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a limited form for free or develop further integrations and capabilities to you needs." : "Wir können auch Outlook-Integration, Online Office, skalierbare integrierte Audio-Video- und Chat-Kommunikation und andere Funktionen anbieten, die nur in begrenzter Form kostenlos zur Verfügung stehen, oder weitere Integrationen und Funktionen nach Ihren Bedürfnissen entwickeln.",
    "A subscription helps you get the most out of Nextcloud!" : "Ein Abonnement hilft Ihnen, das meiste aus Nexcloud herauszuholen!",
    "Learn more now" : "Erfahren Sie jetzt mehr",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Diese E-Mail wurde von der Support-App Ihrer Nextcloud-Instanz unter %1$s an alle Administratoren verschickt, weil über %2$s registrierte Benutzer vorhanden sind.",
    "Your Nextcloud server Subscription is over limit" : "Ihr Nextcloud-Server-Abonnement ist über dem Limit",
    "Dear admin," : "Sehr gehrter Administrator,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "Ihr Nextcloud-Abonnement umfasst nicht die Anzahl der aktuell auf diesem Server aktiven Nutzer. Bitte kontaktieren Sie Ihren Accountmanager, um Ihr Abonnement aktualisieren zu lassen!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s ist Ihr Accountmanager und ist per E-Mail über %2$soder telefonisch unter %3$s erreichbar.",
    "Thank you," : "Dankeschön,",
    "Your Nextcloud team" : "Ihr Nextcloud-Team",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than what your subscription covers." : "Diese E-Mail wurde von der Support-App Ihrer Nextcloud-Instanz unter %s an alle Administratoren verschickt, weil mehr Benutzer registriert sind als das Nextcloud-Abonnement abdeckt.",
    "Your Nextcloud server Subscription is expired" : "Ihr Nextcloud-Server-Abonnement ist abgelaufen",
    "Your Nextcloud server Subscription is expired!" : "Ihr Nextcloud-Server-Abonnement ist abgelaufen!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "Ihr Nextcloud Abonnement ist abgelaufen! Bitte kontaktieren Sie Ihren Accountmanager um das Abonnement verlängert zu bekommen.",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Diese E-Mail wurde von der Support-App Ihrer Nextcloud-Instanz unter %s an alle Administratoren verschickt, weil Ihr Nextcloud-Abonnement abgelaufen ist.",
    "Support" : "Support",
    "Getting support and help for your Nextcloud" : "Erhalten Sie Support und Hilfe für Ihre Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Die Support-App bietet direkten Zugriff auf Hilfe- und Vertriebsquellen, direkte Kontaktmöglichkeiten zum Accountmanager sowie einen Überblick über das Enterprise-Abonnement.",
    "Basic subscription" : "Basis Abonnement",
    "Standard subscription" : "Standard Abonnement",
    "Premium subscription" : "Premium Abonnement",
    "Géant subscription" : "Géant Abonnement",
    "Silver partner subscription" : "Silber-Partner Abonnement",
    "Gold partner subscription" : "Gold-Partner Abonnement",
    "Subscription" : "Abonnement",
    "Over subscription limit" : "Abonnements-Limit überschritten",
    "Valid subscription" : "Gültiges Abonnement",
    "Expired subscription" : "Abgelaufenes Abonnement",
    "Subscription key:" : "Abonnements-Schlüssel:",
    "_Expires in %n year_::_Expires in %n years_" : ["Läuft ab in %n Jahr","Läuft ab in %n Jahren"],
    "_Expires in %n month_::_Expires in %n months_" : ["Läuft ab in %n Monat","Läuft ab in %n Monaten"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Läuft ab in %n Woche","Läuft ab in %n Wochen"],
    "_Expires in %n day_::_Expires in %n days_" : ["Läuft ab in %n Tage","Läuft ab in %n Tagen"],
    "_For %n users_::_For %n users_" : ["Für %n  Nutzer","Für  %n Nutzer"],
    "_currently at %n user_::_currently at %n users_" : ["aktuell mit %n  Nutzer","aktuell mit %n Nutzern"],
    "Includes support for %s" : "Beinhaltet Support für %s",
    "Includes support for %1$s & %2$s" : "Beinhaltet Support für %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Beinhaltet Support für %1$s, %2$s & %3$s",
    "Update subscription key" : "Abonnements-Schlüssel aktualisieren",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s ist Ihr Accountmanager. Zögeren Sie nicht, uns bezüglich Fragen zu Ihrem Abonnement anzusprechen.",
    "You can find answers to common question in our portal and also file support requests there." : "In unserem Portal finden Sie Antworten auf häufige Fragen und können auch Unterstützung anfordern.",
    "Access Nextcloud portal" : "Zum Nextcloud-Portal",
    "System information" : "Systeminformation",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Erstellen von Systeminformationen für Supportfälle. Nach Betätigung der Schaltfläche wird eine Textdatei im Ordner \"System information\" erstellt und über eine passwortgeschütze, öffentliche Freigabe geteilt. Der Link ist 2 Wochen lang aktiv.",
    "Generate system report" : "System-Bericht erstellen",
    "Enterprise subscription recommended" : "Enterprise-Abonnement empfohlen",
    "No active enterprise subscription" : "Kein aktives Enterprise-Abonnement",
    "Unsupported" : "Nicht unterstützt",
    "This Nextcloud server has no Enterprise Subscription." : "Dieser Nextcloud-Server verfügt über kein Enterprise-Abonnement.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Ein Nextcloud Enterprise-Abonnement hilft Ihnen, das Meiste aus Ihrer Nextcloud herauszuholen, Ihre Daten abzusichern und Ihren Server zuverlässig laufen zu lassen.",
    "Advantages" : "Vorteile",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Ein Nextcloud Enterprise-Abonnenment hilft Ihnen, das meiste aus Ihrer Nextcloud herauszuholen, Ihre Daten abzusichern und Ihren Server jederzeit zuverlässig zu betreiben.",
    "Access to additional capabilities like Outlook integration, online office and more" : "Zugriff auf weitere Funktionen wie Outlook-Integration, Online-Office, usw.",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Zugriff auf Skalierbarkeits-Sachverstand und Skalierbarkeits-Fähigkeiten für Dateien und Talk",
    "Optional branding, consulting, architecture advice" : "Optional Unterstützung bezüglich Branding, Beratung und Architektur",
    "Confidential security notification service, mitigations, patches and advice" : "Vertraulicher Sicherheitsbenachrichtigungsdienst, Risikominderung, Patches und Hilfestellungen",
    "Compliance certification, advice and documentation" : "Compliance-Zertifizierung, Beratung und Dokumentation",
    "Get a quote" : "Erhalten Sie ein Angebot",
    "More information" : "Mehr Informationen",
    "Subscription benefits" : "Abonnement-Vorteile",
    "Pricing" : "Preisgestaltung",
    "Commmunity support" : "Community-Unterstützung",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud ist eine freie Software, die von einer sehr aktive Community unterstützt wird. Bitte melden Sie sich im Forum an um Fragen zu stellen oder mit anderen zu diskutieren.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud verwendet GitHub als Plattform für die Zusammenarbeit. Sie können dort Fehler direkt melden.",
    "Chat" : "Chat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Chatten Sie mit uns über den IRC-Kanal #nextcloud auf Freenode.",
    "Nextcloud forum" : "Nextcloud Forum",
    "Nextcloud at GitHub" : "Nextcloud auf GitHub",
    "Open chat" : "Chat öffnen",
    "Subscription key" : "Abonnements-Schlüssel",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Wenn Sie über ein aktives Nextcloud-Abonnement verfügen, geben SIe bitte hier Ihren Abonnements-Schlüssel ein.",
    "Learn more about an enterprise subscription." : "Erfahren Sie mehr über das Enterprise-Abonnement.",
    "Set subscription key" : "Abonnements-Schlüssel eingeben",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Die Abonnenments-Informationen konnten soeben nicht abgerufen werden. Eine Wiederholung ist geplant. Bitte später noch einmal überprüfen.",
    "The subscription key was invalid." : "Der Abonnements-Schlüssel ist ungültig.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Der Abonnements-Schlüssel konnte nicht überprüft werden, da dieser Server nicht mit dem Internet verbunden ist. Bitte wenden Sie sich zur Fehlerbehebung an das Support-Team.",
    "The subscription key had an invalid format." : "Der Abonnements-Schlüssel hat ein ungültiges Format.",
    "While fetching the subscription information an error happened." : "Beim Abruf der Abonnements-Informationen ist ein Fehler aufgetreten",
    "News" : "Neuigkeiten",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Abonnieren Sie unseren Newsletter und folgen Sie uns auf unseren Social-Media-Kanälen um bezüglich der Nexcloud-Entwicklung immer auf dem Laufenden zu sein.",
    "Follow us on Google+" : "Folgen Sie uns auf Google+",
    "Like our Facebook page" : "Liken Sie uns auf unserer Facebook-Seite",
    "Follow us on Twitter" : "Folgen Sie uns auf Twitter",
    "Check out our blog" : "Sehen Sie sich unseren Blog an",
    "Subscribe to our newsletter" : "Abonnieren Sie unseren Newsletter"
},
"nplurals=2; plural=(n != 1);");
